@@ -29,6 +29,8 @@ REGION = 'region_name'
 AZ = 'availability_zone'
 LAUNCH_TIMEOUT = 'launch_timeout_s'
 POST_DELAY = 'post_launch_delay_s'
+SSH_KEY = 'ssh_key_name'
+PROVIDER = 'provider'
 
 # these are ansible magic vars
 INV_NAME = 'inventory_hostname'
